<?php
error_reporting(E_ALL);
ini_set('display_errors', 1);
session_start();

include 'db.php';

$message = '';

function validateEmail($email) {
    return filter_var($email, FILTER_VALIDATE_EMAIL) !== false;
}

// Registration Logic
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['register'])) {
    $username = $_POST['username'];
    $password = $_POST['password']; 
    $email = $_POST['email'];
    $admin_type = $_POST['admin_type'];

    if (!validateEmail($email)) {
        $message = "Invalid email format.";
    } elseif (empty($admin_type)) {
        $message = "Admin type must be selected.";
    } else {
        // Check if username or email is already registered
        $check_stmt = $conn->prepare("SELECT id FROM admin WHERE username = ? OR email = ?");
        if ($check_stmt) {
            $check_stmt->bind_param("ss", $username, $email);
            $check_stmt->execute();
            $check_stmt->store_result();

            if ($check_stmt->num_rows > 0) {
                $message = "Username or email already registered. Please log in.";
            } else {
                // Insert new admin with plain password
                $stmt = $conn->prepare("INSERT INTO admin (username, password, email, admin_type) VALUES (?, ?, ?, ?)");
                if ($stmt) {
                    $stmt->bind_param("sssi", $username, $password, $email, $admin_type); // Use plain password
                    if ($stmt->execute()) {
                        $message = 'Registration successful! Please log in.';
                    } else {
                        $message = 'Registration failed: ' . $stmt->error;
                    }
                    $stmt->close();
                } else {
                    $message = 'Failed to prepare statement for admin insertion.';
                }
            }
            $check_stmt->close();
        } else {
            $message = 'Failed to prepare statement for checking registration.';
        }
    }
}

// Login Logic
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['login'])) {
  $email = $_POST['email'];
  $password = $_POST['password'];

  // Check if email exists
  $stmt = $conn->prepare("SELECT id, username, email, password, admin_type FROM admin WHERE email = ?");
  if ($stmt) {
      $stmt->bind_param("s", $email);
      $stmt->execute();
      $stmt->store_result();
      $stmt->bind_result($admin_id, $admin_username, $admin_email, $stored_password, $admin_type); // Added admin_type

      if ($stmt->num_rows > 0) {
          $stmt->fetch();

// Assuming this is part of your login script
if ($password === $stored_password) {
  $_SESSION['id'] = $admin_id;
  $_SESSION['username'] = $admin_username;
  $_SESSION['email'] = $admin_email;
  $_SESSION['admin_type'] = $admin_type; // This line is crucial
  $_SESSION['loggedin'] = true;
  header("Location: users-list.php"); // Redirect to the admin dashboard or the next appropriate page
  exit();
}
else {
              $message = 'Login failed: Incorrect password.';
          }
      } else {
          $message = 'Login failed: Email not found.';
      }
      $stmt->close();
  } else {
      $message = 'Failed to prepare statement for login.';
  }
}


// Logout Logic
if (isset($_POST['logout'])) {
    session_destroy(); // Destroy session to log out user
    header("Location: login.php"); // Redirect to login/registration page
    exit;
}

// Close connection
$conn->close();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Admin Login and Register</title>
    <link rel="stylesheet" href="index.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.3/css/all.min.css">
    <style>
        .form-content .input-box select {
            height: 100%;
            width: 100%;
            outline: none;
            color: rgb(117, 117, 117) !important;
            border: none;
            padding: 0 30px;
            font-size: 16px;
            font-weight: 500;
            border-bottom: 2px solid rgba(0, 0, 0, 0.2);
            transition: all 0.3s ease;
        }
        .message {
            color: red;
            margin-top: 10px;
        }
    </style>
</head>
<body>
    <div class="container">
        <input type="checkbox" id="flip">
        <div class="cover">
            <div class="front">
                <img src="https://www.brickmarketing.com/wp-content/uploads/2024/02/digital-marketing-700x483.jpg" alt="">
                <div class="text">
                    <span class="text-1">Every new friend is a <br> new adventure</span>
                    <span class="text-2">Let's get connected</span>
                </div>
            </div>
            <div class="back">
                <img src="https://www.brickmarketing.com/wp-content/uploads/2024/02/digital-marketing-700x483.jpg" alt="">
                <div class="text">
                    <span class="text-1">Complete miles of journey <br> with one step</span>
                    <span class="text-2">Let's get started</span>
                </div>
            </div>
        </div>
        <div class="forms">
            <div class="form-content">
                <div class="login-form">
                    <div class="title">Login</div>
                    <form method="post">
                        <div class="input-boxes">
                            <div class="input-box">
                                <i class="fas fa-envelope"></i>
                                <input type="email" name="email" placeholder="Email" required>
                            </div>
                            <div class="input-box">
                                <i class="fas fa-lock"></i>
                                <input type="password" name="password" placeholder="Password" required>
                            </div>
                            <div class="text"><a href="#">Forgot password?</a></div>
                            <div class="button input-box">
                                <input type="submit" name="login" value="Submit">
                            </div>
                            <div class="text sign-up-text">Don't have an account? <label for="flip">Signup now</label></div>
                        </div>
                    </form>
                </div>
                <div class="signup-form">
                    <div class="title">Signup</div>
                    <form method="post">
                        <div class="input-boxes">
                            <div class="input-box">
                                <i class="fas fa-user"></i>
                                <input type="text" name="username" placeholder="Enter your username" required>
                            </div>
                            <div class="input-box">
                                <i class="fas fa-envelope"></i>
                                <input type="email" name="email" placeholder="Enter your email" required>
                            </div>
                            <div class="input-box">
                                <i class="fas fa-lock"></i>
                                <input type="password" name="password" placeholder="Enter your password" required>
                            </div>
                            <div class="input-box">
                                <i class="fas fa-user-tag"></i>
                                <select name="admin_type" required>
                                    <option value="" disabled selected>Select your role</option>
                                    <option value="1">Admin</option>
                                    <option value="2">Staff</option>
                                </select>
                            </div>
                            <div class="button input-box">
                                <input type="submit" name="register" value="Submit">
                            </div>
                            <div class="text sign-up-text">Already have an account? <label for="flip">Login now</label></div>
                        </div>
                    </form>
                </div>
            </div>
        </div>
        <?php if ($message): ?>
            <div class="message"><?php echo htmlspecialchars($message); ?></div>
        <?php endif; ?>
    </div>
</body>
</html>
