<?php
include 'header.php';
include 'db.php'; // Include your database connection file

// Get user_id from URL
$user_id = isset($_GET['user_id']) ? intval($_GET['user_id']) : 0;

// Fetch user information based on user_id
$userQuery = "SELECT id, name , phone, reference_number, my_number, created_at, total_balance, approved FROM MLM_users WHERE id = ?";
$stmt = $conn->prepare($userQuery);
$stmt->bind_param("i", $user_id);
$stmt->execute();
$userResult = $stmt->get_result();
$user = $userResult->fetch_assoc();

if (!$user) {
    echo "<p>User not found!</p>";
    exit;
}

// Fetch user wallet transactions based on user_id
$transactionQuery = "SELECT id, user_id, amount, description, created_at, wallet_type FROM wallet_transactions WHERE user_id = ?";
$stmt = $conn->prepare($transactionQuery);
$stmt->bind_param("i", $user_id);
$stmt->execute();
$transactionResult = $stmt->get_result();

// Initialize variables for balance calculation
$subtotal = 0;
$totalWithdrawal = 0;

// Calculate total balance after withdrawals
while ($transaction = $transactionResult->fetch_assoc()) {
    if ($transaction['wallet_type'] === 'add') {
        $subtotal += $transaction['amount'];
    } elseif ($transaction['wallet_type'] === 'withdrawal') {
        $totalWithdrawal += abs($transaction['amount']); // Use abs() to ensure a positive value
    }
}

// Calculate the current balance
$currentBalance = $subtotal - $totalWithdrawal;


?>

<div class="dashboard-main-body">
    <div class="d-flex flex-wrap align-items-center justify-content-between gap-3 mb-24">
        <h6 class="fw-semibold mb-0">Wallet Transaction for <?php echo htmlspecialchars($user['name']); ?></h6>
    </div>

    <div class="card mt-4">
        <div class="card-header">
            <div class="d-flex flex-wrap align-items-center justify-content-end gap-2">

                <button type="button" class="btn btn-sm btn-danger radius-8 d-inline-flex align-items-center gap-1" onclick="printInvoice()">
                    <iconify-icon icon="basil:printer-outline" class="text-xl"></iconify-icon>
                    Print
                </button>
            </div>
        </div>
<div class="card-body" style="display: flex; justify-content: space-between;">
    <div class="left-side" style="flex: 1; margin-right: 20px;">
        <p><strong>ID:</strong> <?php echo htmlspecialchars($user['id']); ?></p>
        <p><strong>Name:</strong> <?php echo htmlspecialchars($user['name']); ?></p>
        <p><strong>Email:</strong> <?php echo htmlspecialchars($user['email']); ?></p>
        <p><strong>Phone:</strong> <?php echo htmlspecialchars($user['phone']); ?></p>
        <p><strong>Reference Number:</strong> <?php echo htmlspecialchars($user['reference_number']); ?></p>
    </div>
    <div class="right-side" style="flex: 1;">
        <p><strong>My Number:</strong> <?php echo htmlspecialchars($user['my_number']); ?></p>
        <p><strong>Created At:</strong> <?php echo htmlspecialchars($user['created_at']); ?></p>
        <p><strong>Total Balance:</strong> <?php echo htmlspecialchars($currentBalance); ?></p>
        <p><strong>Approved:</strong> <?php echo $user['approved'] ? 'Yes' : 'No'; ?></p>
    </div>
</div>


        <div class="card-body">
        <table class="table bordered-table mb-0" id="dataTable" data-page-length='10' style="min-width: 800px;">
        <thead>
                    <tr>
                        <th>ID</th>
                        <th>Type</th>
                        <th>Amount</th>
                        <th>Description</th>
                        <th>Date</th>

                    </tr>
                </thead>
                <tbody>
                    <?php
                    $stmt->execute();
                    $transactionResult = $stmt->get_result();

// Display wallet transactions
if ($transactionResult->num_rows > 0) {
    while ($transaction = $transactionResult->fetch_assoc()) {
        echo "<tr>";
        echo "<td>" . htmlspecialchars($transaction['id']) . "</td>";
        echo "<td>" . htmlspecialchars($transaction['wallet_type']) . "</td>"; 
        echo "<td>" . htmlspecialchars($transaction['amount']) . "</td>";
        echo "<td>" . htmlspecialchars($transaction['description']) . "</td>";
        echo "<td>" . htmlspecialchars($transaction['created_at']) . "</td>";

        
        echo "</tr>";
    }
} else {
    echo "<tr><td colspan='6'>No transactions found for user ID: " . htmlspecialchars($user_id) . "</td></tr>";
}

                    ?>
                </tbody>
            </table>
            <div class="d-flex flex-wrap justify-content-between gap-3">
                <div>
                    <table class="text-sm">
                        <tbody>
                            <tr>
                                <td class="pe-64">Subtotal :</td>
                                <td class="pe-16">
                                    <span class="text-primary-light fw-semibold"><?php echo '$' . number_format($subtotal, 2); ?></span>
                                </td>
                            </tr>
                            <tr>
                                <td class="pe-64">Withdrawal Amount:</td>
                                <td class="pe-16">
                                    <span class="text-primary-light fw-semibold"><?php echo '$' . number_format($totalWithdrawal, 2); ?></span>
                                </td>
                            </tr>
                            <tr>
                                <td class="pe-64 pt-4">
                                    <span class="text-primary-light fw-semibold">Current Balance:</span>
                                </td>
                                <td class="pe-16 pt-4">
                                    <span class="text-primary-light fw-semibold"><?php echo '$' . number_format($currentBalance, 2); ?></span>
                                </td>
                            </tr>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>
</div>

<?php include 'footer.php'; ?>

<style>


        /* Print styles */
        @media print {
            .print-button {
                display: none; /* Hide print button during printing */
            }

            /* Other print styles */
            .dashboard-main-body {
                -webkit-print-color-adjust: exact; /* Ensure background colors are printed */
                color-adjust: exact;
            }
        }
    </style>

    <script>
        function printInvoice() {
            window.print(); // This will open the print dialog for the entire page
        }
    </script>
