<?php

include 'header.php';
session_start(); 

include 'db.php'; 

$userId = 120;

if (!isset($_SESSION['user_id'])) {
    $_SESSION['user_id'] = $userId; 
}

$query = "SELECT `id`, `name`, `phone`, `reference_number`, `my_number`, `created_at`, `approved` FROM `MLM_users` WHERE `id` = ?";
$stmt = $conn->prepare($query);
$stmt->bind_param("i", $userId);
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows > 0) {
    $user = $result->fetch_assoc();
    $referenceUserId = $user['reference_number']; 
} else {
    echo "No user found with the provided ID.";
    exit;
}

// Function to fetch total amounts based on wallet type and optionally a date condition
function fetchTotalAmount($conn, $userId, $walletType, $dateCondition = '')
{
    $query = "SELECT SUM(amount) AS total FROM wallet_transactions WHERE user_id = ? AND wallet_type = ?";

    // Append date condition if provided
    if ($dateCondition) {
        $query .= " " . $dateCondition;
    }

    $stmt = $conn->prepare($query);
    $stmt->bind_param("is", $userId, $walletType);
    $stmt->execute();
    return $stmt->get_result()->fetch_assoc()['total'] ?? 0; // Return total or 0 if null
}

// Fetch balances and withdrawals with error handling
$userBalance = fetchTotalAmount($conn, $userId, 'add'); // Total balance
if ($userBalance === false) {
    die("Error fetching user balance."); // Handle error in fetching user balance
}

$userWithdraw = fetchTotalAmount($conn, $userId, 'withdrawal'); // Total withdrawals
if ($userWithdraw === false) {
    die("Error fetching user withdrawals."); // Handle error in fetching user withdrawals
}

// Ensure withdrawals are treated as positive for calculation
$userWithdraw = abs($userWithdraw); // Convert withdrawals to positive if needed

// Calculate net balance
$netBalance = $userBalance - $userWithdraw; // Correctly calculate net balance

// Display net balance
// echo "Net Balance = " . $userBalance . " - " . $userWithdraw . " = " . $netBalance . "<br>";

// Fetch today's balance and withdrawals
$todayCondition = 'AND DATE(created_at) = CURDATE()'; // Condition for today's date
$todayBalance = fetchTotalAmount($conn, $userId, 'add', $todayCondition); // Today's deposits
$todayWithdraw = fetchTotalAmount($conn, $userId, 'withdrawal', $todayCondition); // Today's withdrawals

// Fetch reference user's total balance
$referenceUserBalance = fetchTotalAmount($conn, $referenceUserId, 'add');

// Fetch count of users who used the current user's reference number
$refUserCountQuery = "SELECT COUNT(*) AS ref_user_count FROM MLM_users WHERE reference_number = ?";
$stmt = $conn->prepare($refUserCountQuery);
$stmt->bind_param("s", $user['my_number']);
$stmt->execute();
$refUserCount = $stmt->get_result()->fetch_assoc()['ref_user_count'] ?? 0;

// Fetch count of users referred by the current user today
$todayRefUserCountQuery = "SELECT COUNT(*) AS today_ref_user_count FROM MLM_users WHERE reference_number = ? AND DATE(created_at) = CURDATE()";
$stmt = $conn->prepare($todayRefUserCountQuery);
$stmt->bind_param("s", $user['my_number']);
$stmt->execute();
$todayRefUserCount = $stmt->get_result()->fetch_assoc()['today_ref_user_count'] ?? 0;


?>

    <!-- App Capsule -->
   <div id="appCapsule">

        <!-- Wallet Card -->
        <div class="section wallet-card-section pt-1">
            <div class="wallet-card">
                <!-- Balance -->
                <div class="balance">
                    <div class="left">
                        <span class="title">Total Balance</span>
                        <h1 class="total">₹<?php echo htmlspecialchars($netBalance); ?></h1>
                        <p class="text-sm mb-0 d-flex align-items-center flex-wrap gap-12 mt-12">
                        <span class="bg-success-focus px-6 py-2 rounded-2 fw-medium text-success-main text-sm d-flex align-items-center gap-8">
                        ₹ <?php echo htmlspecialchars($todayBalance); ?> <i class="ri-arrow-up-line"></i>
                        </span>
                        Today
                    </p>
                    </div>
                    <div class="right">
                        <a href="#" class="button" data-bs-toggle="modal" data-bs-target="#depositActionSheet">
                            <ion-icon name="add-outline"></ion-icon>
                        </a>
                    </div>
                </div>

            </div>
        </div>
        <!-- Wallet Card -->


 


        <!-- Stats -->
        <div class="section">
            <div class="row mt-2">
                <div class="col-6">
                    <div class="stat-box">
                        <div class="title">Total Withdrawals </div>
                        <div class="value text-success">₹<?php echo htmlspecialchars($userWithdraw); ?></div>
                        <p class="text-sm mb-0 d-flex align-items-center flex-wrap gap-12 mt-12">
                        <span class="bg-danger-focus px-6 py-2 rounded-2 fw-medium text-danger-main text-sm d-flex align-items-center gap-8">
                        ₹<?php echo htmlspecialchars($todayWithdraw); ?> <i class="ri-arrow-down-line"></i>
                        </span> Today
                    </p>
                    </div>
                </div>
                <div class="col-6">
                    <div class="stat-box">
                        <div class="title">Users Referred by                         </div>
                        <div class="value text-danger"><?php echo htmlspecialchars($refUserCount); ?></div>
                        <p class="text-sm mb-0 d-flex align-items-center flex-wrap gap-12 mt-12">
                        <span class="bg-success-focus px-6 py-2 rounded-2 fw-medium text-success-main text-sm d-flex align-items-center gap-8">
                            <?php echo htmlspecialchars($todayRefUserCount); ?> <i class="ri-user-add-line"></i>
                        </span>
                        Today
                    </p>
                    </div>
                </div>
            </div>

        </div>
        <!-- * Stats -->
         
        <?php         include 'chart.php'; ?>

<!-- Transactions -->
<div class="section mt-4">
    <div class="section-heading">
        <h2 class="title">Transactions</h2>
        <a href="app-transactions.html" class="link">View All</a>
    </div>
    <div class="transactions">
        <?php
        // Prepare query to fetch users referred by the current user using my_number
        $transactionsQuery = "SELECT name, phone, reference_number, created_at FROM MLM_users WHERE reference_number = ?";
        $stmt = $conn->prepare($transactionsQuery);
        $stmt->bind_param("s", $user['my_number']); // Bind my_number as string
        $stmt->execute();
        $transactions = $stmt->get_result();
        $counter = 1;

        // Loop through each transaction and display the details
        while ($transaction = $transactions->fetch_assoc()) {
            ?>
            <!-- item -->
            <a href="app-transaction-detail.html" class="item">
                <div class="detail">
                    <div>
                        <strong><?php echo htmlspecialchars($transaction['name']); ?></strong>
                        <p><?php echo htmlspecialchars($transaction['phone']); ?></p>
                    </div>
                </div>
                <div class="right">
                    <!-- Displaying a placeholder price; you can adjust based on your data -->
                    <div class="price">+ $ <?php echo rand(50, 1000); // Placeholder for the price ?></div>
                </div>
            </a>
            <!-- * item -->
        <?php
        }
        ?>
    </div>
</div>
<!-- * Transactions -->


        
        

        <?php  
        

        
        include 'footer.php'; ?>


        <!-- Deposit Action Sheet -->
        <div class="modal fade action-sheet" id="depositActionSheet" tabindex="-1" role="dialog">
            <div class="modal-dialog" role="document">
                <div class="modal-content">
                    <div class="modal-header">
                        <h5 class="modal-title">Add Balance</h5>
                    </div>
                    <div class="modal-body">
                        <div class="action-sheet-content">
                            <form>
                                <div class="form-group basic">
                                    <div class="input-wrapper">
                                        <label class="label" for="account1">From</label>
                                        <select class="form-control custom-select" id="account1">
                                            <option value="0">Savings (*** 5019)</option>
                                            <option value="1">Investment (*** 6212)</option>
                                            <option value="2">Mortgage (*** 5021)</option>
                                        </select>
                                    </div>
                                </div>

                                <div class="form-group basic">
                                    <label class="label">Enter Amount</label>
                                    <div class="input-group mb-2">
                                        <span class="input-group-text" id="basic-addona1">$</span>
                                        <input type="text" class="form-control" placeholder="Enter an amount"
                                            value="100">
                                    </div>
                                </div>


                                <div class="form-group basic">
                                    <button type="button" class="btn btn-primary btn-block btn-lg"
                                        data-bs-dismiss="modal">Deposit</button>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- * Deposit Action Sheet -->