<?php 
include 'header.php'; 
include 'db.php'; 

error_reporting(E_ALL);
ini_set('display_errors', 1);

// Get user ID from session, default to 120 for this example
$user_id = 120;

// SQL query to fetch user's wallet transactions
$query = "SELECT `id`, `user_id`, `amount`, `description`, `created_at`, `wallet_type` 
          FROM `wallet_transactions` 
          WHERE `user_id` = ? 
          ORDER BY `created_at` DESC";

// Prepare and execute the statement
$stmt = $conn->prepare($query);
$stmt->bind_param("i", $user_id); // 'i' indicates that the parameter is an integer
$stmt->execute();
$result = $stmt->get_result(); // Get the result set from the prepared statement

// Fetch all transactions
$transactions = $result->fetch_all(MYSQLI_ASSOC); // Fetch associative array

// Debug output to check the fetched transactions
if (empty($transactions)) {
    // echo "No transactions found for User ID: $user_id"; // Add this line for debugging
} else {

}
?>

<div class="section mt-2" >
    <div class="card" style="padding: 20px; margin-top: 80px; margin-bottom: 20px;">
        <div style="display: flex; align-items: center; flex-wrap: wrap; gap: 10px; justify-content: space-between; margin-bottom: 20px;">
            <h4 class="mb-2 fw-bold text-lg mb-0">User Transaction History</h4>
            <div style="display: flex; gap: 10px;">
                <input type="text" id="searchInput" class="form-control form-control-sm w-auto" placeholder="Search..." />
                <select id="transactionFilter" class="form-select form-select-sm w-auto bg-base border text-secondary-light">
                    <option value="all">All</option>
                    <option value="add">Add</option>
                    <option value="withdrawal">Withdrawal</option>
                </select>
            </div>
        </div>
        <div class="table-responsive">
            <table class="table bordered-table mb-0">
                <thead>
                    <tr>
                        <th scope="col">S.L</th>
                        <th scope="col">User ID</th>
                        <th scope="col">Description (Transaction Type)</th>
                        <th scope="col">Created At</th>
                        <th scope="col">Amount</th>
                        <th scope="col">Wallet Type</th>
                    </tr>
                </thead>
                <tbody id="transactionTableBody">
                    <?php
                    $counter = 1;
                    foreach ($transactions as $transaction) {
                        echo "<tr>";
                        echo "<td>{$counter}</td>";
                        echo "<td>{$transaction['user_id']}</td>";
                        echo "<td>{$transaction['description']}</td>";
                        echo "<td>{$transaction['created_at']}</td>";
                        echo "<td>₹" . number_format($transaction['amount'], 2) . "</td>";
                        echo "<td>
                                <span class='px-24 py-4 rounded-pill fw-medium text-sm " . 
                                ($transaction['wallet_type'] == 'add' ? 'bg-wallet-add text-wallet-add' : 'bg-wallet-withdrawal text-wallet-withdrawal') . "'>
                                    " . ucfirst($transaction['wallet_type']) . "
                                </span>
                              </td>";
                        echo "</tr>";
                        $counter++;
                    }
                    ?>
                </tbody>
            </table>
        </div>
        <div id="pagination" class="mt-3 d-flex justify-content-center"></div>
    </div>
</div>

<script>
    // Search and filter logic
    const searchInput = document.getElementById('searchInput');
    const transactionFilter = document.getElementById('transactionFilter');
    const transactionTableBody = document.getElementById('transactionTableBody');

    // Function to filter transactions based on search and filter criteria
    function filterTransactions() {
        const searchTerm = searchInput.value.toLowerCase();
        const filterValue = transactionFilter.value.toLowerCase();
        const rows = transactionTableBody.getElementsByTagName('tr');

        for (let row of rows) {
            const description = row.cells[2].innerText.toLowerCase();
            const walletType = row.cells[5].innerText.toLowerCase();
            const matchesSearch = description.includes(searchTerm) || walletType.includes(searchTerm);
            const matchesFilter = filterValue === 'all' || walletType === filterValue;

            row.style.display = (matchesSearch && matchesFilter) ? '' : 'none';
        }
    }

    // Add event listeners for search input and filter dropdown
    searchInput.addEventListener('input', filterTransactions);
    transactionFilter.addEventListener('change', filterTransactions);
</script>

<style>
    /* .bg-wallet-withdrawal {
        background-color: #f4433640 !important; 
    } */

    .text-wallet-withdrawal {
        color: #c62828 !important; 
    }

    /* .bg-wallet-add {
        background-color: rgba(76, 175, 80, 0.1) !important; 
    } */

    .text-wallet-add {
        color: #00796b !important;
    }
</style>

<?php include 'footer.php'; ?>
