<?php 
session_start();
include 'db.php'; 
include 'header.php'; 
?>

<div class="dashboard-main-body">
    <div class="d-flex flex-wrap align-items-center justify-content-between gap-3 mb-24">
        <h6 class="fw-semibold mb-0"></h6>
        <ul class="d-flex align-items-center gap-2">
            <li class="fw-medium">
                <a href="index.php" class="d-flex align-items-center gap-1 hover-text-primary">
                    <iconify-icon icon="solar:home-smile-angle-outline" class="icon text-lg"></iconify-icon>
                    Dashboard
                </a>
                <li>-</li>
                <li class="fw-medium">Withdrawal Requests</li>
            </li>
        </ul>
    </div>

    <div class="card basic-data-table">
        <div class="card-body">
            <div class="d-flex align-items-center flex-wrap gap-2 justify-content-between mb-20">
                <h6 class="mb-2 fw-bold text-lg mb-0">Withdrawal Requests</h6>
                <select id="transactionFilter" class="form-select form-select-sm w-auto bg-base border text-secondary-light">
                    <option value="all">All</option>
                    <option value="withdrawal">Withdrawal</option>
                    <option value="pending">Pending</option>
                    <option value="rejected">Rejected</option>
                </select>
            </div>

            <div class="table-responsive">
                <table class="table bordered-table mb-0" id="dataTable" data-page-length='10'>
                    <thead>
                        <tr>
                            <th scope="col">S.L</th>
                            <th scope="col">User ID</th>
                            <th scope="col">User Name</th>
                            <th scope="col">Bank Name</th>
                            <th scope="col">Bank Number</th>
                            <th scope="col">Withdrawal Amount</th>
                            <th scope="col">Branch</th>
                            <th scope="col">Type</th>
                            <th scope="col">Created At</th>
                        </tr>
                    </thead>
                    <tbody id="transactionTableBody">
                    <?php
                    // Fetching withdrawal requests from the database
                    $query = "SELECT `id`, `user_id`, `user_name`, `bank_name`, `bank_number`, `withdrawal_amount`, `branch`, `type`, `created_at` FROM `payment_withdrawals`";
                    
                    // Prepare and execute the query
                    $stmt = $conn->prepare($query);
                    if ($stmt) {
                        $stmt->execute();
                        $result = $stmt->get_result();

                        // Initialize serial number counter
                        $sl = 1;

                        // Check if there are any results
                        if ($result->num_rows > 0) {
                            // Loop through each row and display it
                            while ($row = $result->fetch_assoc()) {
                                // Determine classes for the wallet type
                                $wallet_type_class = '';
                                $wallet_type_text_class = '';

                                if ($row['type'] == 'withdrawal') {
                                    $wallet_type_class = 'bg-wallet-withdrawal';
                                    $wallet_type_text_class = 'text-wallet-withdrawal';
                                } elseif ($row['type'] == 'pending') {
                                    $wallet_type_class = 'bg-wallet-pending';
                                    $wallet_type_text_class = 'text-wallet-pending';
                                } elseif ($row['type'] == 'rejected') {
                                    $wallet_type_class = 'bg-wallet-reject';
                                    $wallet_type_text_class = 'text-wallet-reject';
                                }

                                echo "<tr data-wallet-type='{$row['type']}'>
                                        <td>{$sl}</td>
                                        <td>{$row['user_id']}</td>
                                        <td>{$row['user_name']}</td>
                                        <td>{$row['bank_name']}</td>
                                        <td>{$row['bank_number']}</td>
                                        <td>₹{$row['withdrawal_amount']}</td>
                                        <td>{$row['branch']}</td>
                                        <td>
                                            <span class='px-24 py-4 rounded-pill fw-medium text-sm {$wallet_type_class} {$wallet_type_text_class}'>
                                                {$row['type']}
                                            </span>
                                        </td>
                                        <td>{$row['created_at']}</td>
                                      </tr>";
                                $sl++;
                            }
                        } else {
                            echo "<tr><td colspan='9'>No withdrawal requests found.</td></tr>";
                        }

                        // Close the statement
                        $stmt->close();
                    } else {
                        echo "<tr><td colspan='9'>Error preparing the statement.</td></tr>";
                    }

                    // Close the connection
                    $conn->close();
                    ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</div>

<?php include 'footer.php'; ?>

<script>
    document.getElementById('transactionFilter').addEventListener('change', function() {
        const filterValue = this.value;

        // Get all table rows from the table body with id 'transactionTableBody'
        const rows = document.querySelectorAll('#transactionTableBody tr');

        rows.forEach(row => {
            const walletType = row.getAttribute('data-wallet-type');

            // Show or hide rows based on the selected filter
            if (filterValue === 'all' || filterValue === walletType) {
                row.style.display = '';  // Show the row
            } else {
                row.style.display = 'none';  // Hide the row
            }
        });
    });
</script>

<!-- Styles for Withdrawal, Pending, and Rejected Statuses -->
<style>
    /* Withdrawal styles (green) */
    .bg-wallet-withdrawal {
        background-color: rgba(76, 175, 80, 0.1) !important; /* Light green background with reduced opacity */
    }

    .text-wallet-withdrawal {
        color: #4CAF50 !important; /* Green text color */
    }

    /* Pending styles (yellow) */
    .bg-wallet-pending {
        background-color: rgba(255, 193, 7, 0.1) !important; /* Light yellow background with reduced opacity */
    }

    .text-wallet-pending {
        color: #FFC107 !important; /* Yellow text color */
    }

    /* Rejected styles (red) */
    .bg-wallet-reject {
        background-color: rgba(244, 67, 54, 0.1) !important; /* Light red background with reduced opacity */
    }

    .text-wallet-reject {
        color: #F44336 !important; /* Red text color */
    }

    /* Scrollable table style */
    .table-responsive {
        max-height: 400px; /* Set your desired height */
        overflow-y: auto; /* Enable vertical scrolling */
    }
</style>


<script>
    // Apply class to the Type column based on its value
    document.querySelectorAll('#transactionTableBody tr').forEach(row => {
        const typeCell = row.querySelector('.type-column');
        const walletType = row.getAttribute('data-wallet-type');
        
        if (walletType === 'withdrawal') {
            typeCell.classList.add('withdrawal');
        } else if (walletType === 'pending') {
            typeCell.classList.add('pending');
        } else if (walletType === 'rejected') {
            typeCell.classList.add('rejected');
        }
    });
</script>
